@@ -13,24 +13,24 @@ test_that("textplot_* works with SVD", {
   seed <- c("nice*" = 1, "positive*" = 1, "bad*" = -1, "negative*" = -1)
   lss <- textmodel_lss(dfmt, seed, k = 10)
   suppressWarnings({
-    is_ggplot(textplot_simil(lss))
+    expect_true(is_ggplot(textplot_simil(lss)))
   })
-  is_ggplot(textplot_terms(lss, highlighted = dict$keywords))
-  is_ggplot(textplot_terms(lss, highlighted = dict$keywords, max_words = 2))
-  is_ggplot(textplot_terms(lss, highlighted = dict$keywords, max_highlighted = 10))
-  is_ggplot(textplot_terms(lss, highlighted = dict$keywords, max_highlighted = 0))
-  is_ggplot(textplot_terms(lss, highlighted = dict))
-  is_ggplot(textplot_terms(lss, highlighted = character()))
-  is_ggplot(textplot_terms(lss))
-  is_ggplot(textplot_terms(lss, max_highlighted = 10))
-  is_ggplot(textplot_terms(lss, sampling = "relative"))
-  is_ggplot(textplot_terms(lss, sampling = "absolute"))
+  expect_true(is_ggplot(textplot_terms(lss, highlighted = dict$keywords)))
+  expect_true(is_ggplot(textplot_terms(lss, highlighted = dict$keywords, max_words = 2)))
+  expect_true(is_ggplot(textplot_terms(lss, highlighted = dict$keywords, max_highlighted = 10)))
+  expect_true(is_ggplot(textplot_terms(lss, highlighted = dict$keywords, max_highlighted = 0)))
+  expect_true(is_ggplot(textplot_terms(lss, highlighted = dict)))
+  expect_true(is_ggplot(textplot_terms(lss, highlighted = character())))
+  expect_true(is_ggplot(textplot_terms(lss)))
+  expect_true(is_ggplot(textplot_terms(lss, max_highlighted = 10)))
+  expect_true(is_ggplot(textplot_terms(lss, sampling = "relative")))
+  expect_true(is_ggplot(textplot_terms(lss, sampling = "absolute")))
   expect_error(textplot_terms(lss, sampling = "xxx"))
 
   lss2 <- textmodel_lss(dfmt, seed, terms = feat_test, k = 10)
-  is_ggplot(textplot_terms(lss2))
-  is_ggplot(textplot_terms(lss2, sampling = "relative"))
-  is_ggplot(textplot_terms(lss2, sampling = "absolute"))
+  expect_true(is_ggplot(textplot_terms(lss2)))
+  expect_true(is_ggplot(textplot_terms(lss2, sampling = "relative")))
+  expect_true(is_ggplot(textplot_terms(lss2, sampling = "absolute")))
   expect_error(textplot_terms(lss2, sampling = "xxx"))
 })
 
@@ -39,7 +39,7 @@ test_that("textplot_* works even when frequency and beta do not match (#71)", {
   seed <- c("nice*" = 1, "positive*" = 1, "bad*" = -1, "negative*" = -1)
   lss <- textmodel_lss(dfmt, seed, k = 10)
   lss$frequency <- c(lss$frequency, "xxx" = 1, "yyy" = 1) # replicate #71
-  is_ggplot(textplot_terms(lss))
+  expect_true(is_ggplot(textplot_terms(lss)))
 })
 
 test_that("textplot_* works with Glove", {
@@ -47,17 +47,17 @@ test_that("textplot_* works with Glove", {
   seed <- c("nice*" = 1, "positive*" = 1, "bad*" = -1, "negative*" = -1)
   lss <- textmodel_lss(fcmt, seed, w = 10)
   suppressWarnings({
-    is_ggplot(textplot_simil(lss))
+    expect_true(is_ggplot(textplot_simil(lss)))
   })
-  is_ggplot(textplot_terms(lss, highlighted = dict$keywords))
-  is_ggplot(textplot_terms(lss, highlighted = dict$keywords, max_words = 2))
-  is_ggplot(textplot_terms(lss, highlighted = dict))
-  is_ggplot(textplot_terms(lss))
+  expect_true(is_ggplot(textplot_terms(lss, highlighted = dict$keywords)))
+  expect_true(is_ggplot(textplot_terms(lss, highlighted = dict$keywords, max_words = 2)))
+  expect_true(is_ggplot(textplot_terms(lss, highlighted = dict)))
+  expect_true(is_ggplot(textplot_terms(lss)))
   expect_error(textplot_terms(lss, highlighted = dict, max_words = 100:200),
                "The length of max_words must be 1")
 
   lss2 <- textmodel_lss(fcmt, seed, terms = feat_test, w = 10)
-  is_ggplot(textplot_terms(lss2))
+  expect_true(is_ggplot(textplot_terms(lss2)))
 })
 
 test_that("textplot_components() works", {
@@ -74,8 +74,8 @@ test_that("textplot_components() works", {
   gg2 <- textplot_components(lss_svd, n = 3)
   expect_equal(length(levels(gg2$data$group)), 3)
 
-  is_ggplot(textplot_components(lss_svd, 3))
-  is_ggplot(textplot_components(lss_svd, 3, scale = "relative"))
+  expect_true(is_ggplot(textplot_components(lss_svd, 3)))
+  expect_true(is_ggplot(textplot_components(lss_svd, 3, scale = "relative")))
   expect_error(textplot_components(lss_svd, n = c(5, 6)), "The length of n must be 1")
   expect_error(textplot_components(lss_svd, n = 20), "The value of n must be between 2 and 10")
   expect_error(textplot_components(lss_glove), "SVD must be used to generate word vectors")
@@ -100,7 +100,7 @@ test_that("textplot_terms works even when frequency has zeros (#85)", {
     lss <- textmodel_lss(dfmt, seed, k = 10)
   )
   expect_true(any(lss$frequency == 0))
-  is_ggplot(textplot_terms(lss))
+  expect_true(is_ggplot(textplot_terms(lss)))
   expect_silent(print(textplot_terms(lss, max_highlighted = 10)))
 })
 
